# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1] - 2021-04-16
### Added
- First (working) version of the algorithm.
- Example usage for a TSO case under `examples`.
- Installation files.
### Upgraded
- `setup.cfg` file has metadata info with long description.
